STEP_NAMES = [
    "Hiện tượng Neo",
    "Bảng câu hỏi",
    "Thí nghiệm",
    "Xây dựng mô hình",
    "Thách thức",
]

QUESTIONS = [
    {
        "id": 1,
        "title": "Nồi cơm điện",
        "question": "Tại sao nắp nồi cơm điện rung và có hơi nước?",
        "topic": "Chuyển thể, bay hơi",
        "icon": "🍚",
        "level": "basic",
        "gradeRange": "4-5",
    },
    {
        "id": 2,
        "title": "Sương mù Đà Lạt",
        "question": "Tại sao Đà Lạt sáng sớm có sương mù, trưa tan hết?",
        "topic": "Chu trình nước, ngưng tụ",
        "icon": "🌫",
        "level": "basic",
        "gradeRange": "4-5",
    },
    {
        "id": 3,
        "title": "Rừng ngập mặn",
        "question": "Tại sao cây bần/đước sống được trong nước mặn?",
        "topic": "Tế bào, thẩm thấu",
        "icon": "🌳",
        "level": "advanced",
        "gradeRange": "8-9",
    },
    {
        "id": 4,
        "title": "Giọt nước trên ly đá",
        "question": "Tại sao bên ngoài ly đá có giọt nước bám?",
        "topic": "Ngưng tụ, điểm sương",
        "icon": "🧊",
        "level": "basic",
        "gradeRange": "3-4",
    },
    {
        "id": 5,
        "title": "Muối biển",
        "question": "Tại sao muối biển lấy được bằng cách phơi nắng?",
        "topic": "Bay hơi, tách hỗn hợp",
        "icon": "🧂",
        "level": "basic",
        "gradeRange": "4-5",
    },
    {
        "id": 6,
        "title": "Cầu vồng",
        "question": "Tại sao cầu vồng xuất hiện sau cơn mưa?",
        "topic": "Khúc xạ ánh sáng, quang phổ",
        "icon": "🌈",
        "level": "advanced",
        "gradeRange": "6-7",
    },
    {
        "id": 7,
        "title": "Pha mặt trăng",
        "question": "Tại sao mặt trăng thay đổi hình dạng mỗi đêm?",
        "topic": "Pha mặt trăng, phản xạ",
        "icon": "🌙",
        "level": "basic",
        "gradeRange": "4-5",
    },
    {
        "id": 8,
        "title": "Tiếng trống",
        "question": "Tại sao đập trống phát ra tiếng vang?",
        "topic": "Sóng âm, rung động",
        "icon": "🥁",
        "level": "basic",
        "gradeRange": "4-5",
    },
    {
        "id": 9,
        "title": "Quạt điện",
        "question": "Tại sao quạt điện quay khi cắm điện?",
        "topic": "Mạch điện, chuyển hóa năng lượng",
        "icon": "🔌",
        "level": "basic",
        "gradeRange": "4-5",
    },
    {
        "id": 10,
        "title": "Nam châm",
        "question": "Tại sao nam châm hút đinh sắt nhưng không hút nhôm?",
        "topic": "Từ tính, vật liệu sắt từ",
        "icon": "🧲",
        "level": "intermediate",
        "gradeRange": "5-6",
    },
    {
        "id": 11,
        "title": "Xe đạp xuống dốc",
        "question": "Tại sao xe đạp đi nhanh hơn khi xuống dốc?",
        "topic": "Trọng lực, thế năng/động năng",
        "icon": "🚲",
        "level": "advanced",
        "gradeRange": "7",
    },
    {
        "id": 12,
        "title": "Lá cây xanh",
        "question": "Tại sao lá cây xanh nhưng hoa có nhiều màu?",
        "topic": "Quang hợp, sắc tố",
        "icon": "🌿",
        "level": "intermediate",
        "gradeRange": "5-6",
    },
    {
        "id": 13,
        "title": "Bóng đèn",
        "question": "Tại sao bóng đèn phát sáng khi bật công tắc?",
        "topic": "Mạch điện, năng lượng điện → quang",
        "icon": "💡",
        "level": "basic",
        "gradeRange": "4-5",
    },
    {
        "id": 14,
        "title": "Rỉ sét",
        "question": "Tại sao sắt để ngoài mưa bị rỉ sét?",
        "topic": "Oxy hóa, biến đổi hóa học",
        "icon": "🔩",
        "level": "advanced",
        "gradeRange": "7-8",
    },
    {
        "id": 15,
        "title": "Cá thở dưới nước",
        "question": "Tại sao cá sống được dưới nước?",
        "topic": "Hô hấp, mang cá, oxy hòa tan",
        "icon": "🐟",
        "level": "basic",
        "gradeRange": "4-5",
    },
    {
        "id": 16,
        "title": "Nước ngọt có ga",
        "question": "Tại sao mở chai nước ngọt có ga bọt phun ra?",
        "topic": "Độ tan khí, áp suất",
        "icon": "🥤",
        "level": "intermediate",
        "gradeRange": "5-6",
    },
    {
        "id": 17,
        "title": "Kem tan chảy",
        "question": "Tại sao kem tan nhanh ngoài nắng?",
        "topic": "Nóng chảy, truyền nhiệt",
        "icon": "🍦",
        "level": "basic",
        "gradeRange": "3-4",
    },
    {
        "id": 18,
        "title": "Bóng bay heli",
        "question": "Tại sao bóng bay heli bay lên trời?",
        "topic": "Mật độ, lực đẩy Archimedes",
        "icon": "🎈",
        "level": "advanced",
        "gradeRange": "6-8",
    },
    {
        "id": 19,
        "title": "Đom đóm",
        "question": "Tại sao đom đóm phát sáng trong đêm?",
        "topic": "Phát quang sinh học, hóa năng → quang",
        "icon": "✨",
        "level": "intermediate",
        "gradeRange": "5-6",
    },
    {
        "id": 20,
        "title": "Chai nước xylophone",
        "question": "Tại sao gõ chai nước khác mức nghe khác nhau?",
        "topic": "Tần số âm, cột không khí",
        "icon": "🎵",
        "level": "basic",
        "gradeRange": "4-5",
    },
]


def get_question_by_id(question_id: int):
    for item in QUESTIONS:
        if item["id"] == question_id:
            return item
    return None
